@@ -19,7 +19,7 @@ from ._dispatcher import Dispatcher
 from ._errors import Error, ErrorEnum
 from ._request import BatchRequest, Request
 from ._response import BatchResponse, Response
-from ._serializer import JSONSerializer
+from ._serializer import JSONSerializer, PickleSerializer
 from ._wsgi import WSGIHandler
 
 __all__: Final[list[str]] = [
@@ -29,9 +29,10 @@ __all__: Final[list[str]] = [
     "Error",
     "ErrorEnum",
     "JSONSerializer",
+    "PickleSerializer",
     "Request",
     "Response",
     "WSGIHandler"
 ]
 
-__version__: Final[str] = "2.2.1"
+__version__: Final[str] = "2.2.2"
