@@ -117,9 +117,9 @@ class Response(BaseResponse):
 
     def __eq__(self, obj: Any, /) -> bool:
         return isinstance(obj, self.__class__) \
-            and type(self._body) == type(obj._body) and self._body == obj._body \
-            and type(self._error) == type(obj._error) and self._error == obj._error \
-            and type(self._id) == type(obj._id) and self._id == obj._id
+            and type(self._body) is type(obj._body) and self._body == obj._body \
+            and type(self._error) is type(obj._error) and self._error == obj._error \
+            and type(self._id) is type(obj._id) and self._id == obj._id
 
     def _is_body_and_error_valid(self, *, body: Any, error: Error | UndefinedType) -> None:
         if isinstance(body, UndefinedType) == isinstance(error, UndefinedType):
