@@ -18,20 +18,20 @@ from types import TracebackType
 from typing import Any, Final, Protocol, TypeAlias
 
 __all__: Final[list[str]] = [
-    "ExcInfo",
     "Headers",
     "InputStream",
+    "OptExcInfo",
     "StartResponse",
     "WSGIEnvironment"
 ]
 
 Headers: TypeAlias = MutableSequence[tuple[str, str]]
-ExcInfo: TypeAlias = tuple[type[Exception], Exception, TracebackType | None]
+OptExcInfo: TypeAlias = tuple[type[Exception], Exception, TracebackType] | tuple[None, None, None]
 WSGIEnvironment: TypeAlias = MutableMapping[str, Any]
 
 
 class StartResponse(Protocol):
-    def __call__(self, __status: str, __headers: Headers, __exc_info: ExcInfo | None = ..., /) -> Any: ...
+    def __call__(self, __status: str, __headers: Headers, __exc_info: OptExcInfo | None = ..., /) -> Any: ...
 
 
 class InputStream(Iterable[bytes], Protocol):
